@@ -1,7 +1,7 @@
 package Graphics::Primitive::Border;
 use Moose;
 
-extends 'Graphics::Primitive::Stroke';
+extends 'Graphics::Primitive::Brush';
 
 use Graphics::Color;
 
@@ -11,6 +11,8 @@ has 'color' => (
 );
 has '+width' => ( default => sub { 0 });
 
+__PACKAGE__->meta->make_immutable;
+
 no Moose;
 1;
 __END__
@@ -40,9 +42,9 @@ component.
 
 =item I<new>
 
-Creates a new Graphics::Primitiver::Border.  Border extends Stroke and adds a
+Creates a new Graphics::Primitiver::Border.  Border extends Brush and adds a
 color attribute. Has a default stroke if none is specified.  See the
-documentation for L<Graphics::Primitive::Stroke> for more information.
+documentation for L<Graphics::Primitive::Brush> for more information.
 
 =back
 
