@@ -2,7 +2,7 @@ package # hide from the CPAN
     DummyDriver;
 use Moose;
 
-extends 'Graphics::Primitive::Driver';
+with 'Graphics::Primitive::Driver';
 
 has 'draw_component_called' => (
     is => 'rw',
@@ -10,6 +10,10 @@ has 'draw_component_called' => (
     default => sub { 0 }
 );
 
+sub _do_stroke { }
+
+sub _draw_canvas { }
+
 sub _draw_component {
     my ($self, $comp) = @_;
 
@@ -18,5 +22,15 @@ sub _draw_component {
     );
 }
 
+sub _draw_line { }
+
+sub _draw_textbox { }
+
+sub data { }
+
+sub get_text_bounding_box { }
+
+sub write { }
+
 no Moose;
 1;
\ No newline at end of file
